/*
 * Copyright (c) 2009-2017, REWOO Technologies AG
 * All rights reserved.
 */

package com.rewoo.realm.api;

import org.apache.shiro.authc.AuthenticationToken;

/**
 * An IRealmDatasource provides access to the user data of a realm (e.g. to the database containing the user data,
 * an ldap server, ...). It is up to the realm-implementation whether it provides the datasource on its own or asks
 * REWOO Scope for injecting an appropriate one.
 * @param <T> Credential type (most of the time a String for a password, but might be also a byte-array for a token or any other class)
 */
public interface IRealmDatasource <T> {
    /**
     * Checks, if the passed user can be authenticated with the supplied password
     * @param username The name of the user ("principal" in shiro terminology)
     * @param credential The secret the user supplies to authenticate himself
     * @return true, if the user can be authenticated. False otherwise
     */
    public boolean isCredentialValid(String username, T credential);

    /**
    * Checks, if the passed user exists at all within the
    * @return true, if the user exists. False otherwise
    */
    public boolean userExists(String username);
}
