/*
 * Copyright (c) 2009-2017, REWOO Technologies AG
 * All rights reserved.
 */

package com.rewoo.realm.api;

import org.apache.shiro.authc.Account;
import org.apache.shiro.authc.AuthenticationToken;

/**
 * This SPI can be used to defined pluggable authentication modules for REWOO Scope.
 * Each pam can check whether the passed token belongs to a certain "realm" or not. A token contains
 * some kind of "user identification" (like a username) and some secret (like a password).
 * Examples for realms are the internal Scope user database, an external LDAP directory,
 * or any other "authentication datasource".
 *
 * The central point of each implementation is the authentication-method: it is responsible
 * for checking whether the passed token authenticates a user within the current realm or not.
 * @param <T> The authentication token this realm can understand
 *
 * Be aware that implementing classes need a public constructor of the following format:
 * public CLASSNAME(List<IRealmDatasource> realmDatasources, Map<String, String> config)
 *
 */
public interface IScopeShiroRealm <T extends AuthenticationToken> {
    public Account authenticate(T token);
    public Class<T> getAuthTokenClass();
}
