package com.rewoo.realm.util;

import java.util.*;

public class RealmMetadata {
    private String uniqueName;
    private String displayName;
    private String description;
    private String mainClass;
    private List<String> realmDatasources;
    private Map<String, String> config;

    // Added for GSON
    public RealmMetadata() {}

    private RealmMetadata(RealmMetadata toCopy) {
        this.uniqueName = toCopy.uniqueName;
        this.displayName = toCopy.displayName;
        this.description = toCopy.description;
        this.mainClass = toCopy.mainClass;
        this.realmDatasources = new ArrayList<>(toCopy.realmDatasources);
        this.config = new HashMap<String, String>(toCopy.config);
    }

    public String getUniqueName() {
        return uniqueName;
    }

    public String getDisplayName() {
        return displayName;
    }

    public String getDescription() {
        return description;
    }

    public String getMainClass() {
        return mainClass;
    }

    public List<String> getRealmDatasources() {
        return Collections.unmodifiableList(realmDatasources);
    }

    public Map<String, String> getConfig() {
        return Collections.unmodifiableMap(config);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        RealmMetadata that = (RealmMetadata) o;

        return uniqueName.equals(that.uniqueName);
    }

    @Override
    public int hashCode() {
        return uniqueName.hashCode();
    }

    public RealmMetadata createWithOverwrittenConfigs(Map<String, String> configToOverwrite) {
        RealmMetadata copy = new RealmMetadata(this);
        copy.config.putAll(configToOverwrite);
        return copy;
    }
}
