package com.rewoo.realm.util;

import com.google.gson.Gson;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Map;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;

public final class RealmMetadataReader {
    private static final Logger logger = LoggerFactory.getLogger(RealmMetadataReader.class);
    private static final String METADATA_FILENAME = "realm-meta.json";
    private static final String CONFIG_KEY = "config";

    private RealmMetadataReader() {
        throw new AssertionError("Do not instantiate a utility class!");
    }

    public static RealmMetadata readMetadata(File realmJar) throws IOException {
        JarFile jarFile = null;
        BufferedReader metaDataStream = null;
        try {
            jarFile = new JarFile(realmJar);
            JarEntry metaDataFile = jarFile.getJarEntry(METADATA_FILENAME);
            if (metaDataFile == null) {
                logger.warn("Found no " + METADATA_FILENAME + " within realm plugin " + realmJar.getAbsolutePath() + ". Returning null");
                return null;
            }
            Gson gson = new Gson();
            metaDataStream = new BufferedReader(new InputStreamReader(jarFile.getInputStream(metaDataFile)));
            return gson.fromJson(metaDataStream, RealmMetadata.class);
        } finally {
            if (metaDataStream != null) {
                metaDataStream.close();
            }
            if (jarFile != null) {
                jarFile.close();
            }
        }
    }
}
